uniform sampler2D TexToUse;

// water parameters
uniform float wred;
uniform float wgreen;
uniform float wblue;
uniform float wbrightness;
uniform float wsaturation;
uniform float wcontrast;
uniform float flattenWater;

// land parameters
uniform float lred;
uniform float lgreen;
uniform float lblue;
uniform float lbrightness;
uniform float lsaturation;
uniform float lcontrast;
uniform float flattenLand;

// For all settings: 1.0 = 100% 0.5=50% 1.5 = 150%
vec3 ContrastSaturationBrightness(vec3 color, float brt, float sat, float con)
{
	// Increase or decrease theese values to adjust r, g and b color channels seperately
	const float AvgLumR = 0.5;
	const float AvgLumG = 0.5;
	const float AvgLumB = 0.5;

	const vec3 LumCoeff = vec3(0.2125, 0.7154, 0.0721);

	vec3 AvgLumin = vec3(AvgLumR, AvgLumG, AvgLumB);
	vec3 brtColor = color * brt;
	vec3 intensity = vec3(dot(brtColor, LumCoeff));
	vec3 satColor = mix(intensity, brtColor, sat);
	vec3 conColor = mix(AvgLumin, satColor, con);
	return conColor;
}

void main(void)
{

  if (gl_TexCoord[0].s < 0 || gl_TexCoord[0].s > 1) discard;
  if (gl_TexCoord[0].t < 0 || gl_TexCoord[0].t > 1) discard;  

  vec4 color = vec4(vec3(texture2D(TexToUse, gl_TexCoord[0].st)),1.0);

  // is this a water frag?
  if ( color.b + 0.10 >= color.g && color.b >= (color.r + 0.02) )
  {
     if ( flattenWater == 1.0 )
     {
        color.rgb = vec3(wred,wgreen,wblue);
     }
     else
     {
        color.rgb = ContrastSaturationBrightness(color.rgb, wbrightness, wsaturation, wcontrast );
     }
  }
  // is this a black-ish frag?
  else if ( color.b <= 0.05 && color.r <= 0.05 && color.g <= 0.05 )
  {
     // treat black-ish as water for now ;)
     if ( flattenWater == 1.0 )
     {
        color.rgb = vec3(wred,wgreen,wblue);
     }
     else
     {
        color.rgb = ContrastSaturationBrightness(color.rgb, wbrightness, wsaturation, wcontrast );
     }
  }
  // must be land
  else
  {
     if ( flattenLand == 1.0 )
     {
        color.rgb = vec3(lred,lgreen,lblue);
     }
     else
     {
        color.rgb = ContrastSaturationBrightness(color.rgb, lbrightness, lsaturation, lcontrast );
     }
  }
  

  gl_FragColor = color;
}